@@ -225,83 +225,215 @@ class Channel(DiscordObjectBase):
         """
         return self.client.bulk_delete_messages(self, *messages, reason=reason)
 
-    def edit_permissions(self, overwrite, *, reason: str = None):
+    def edit_permissions(self, overwrite, *, reason: Optional[str] = None):
+        """
+        Edits permissions.
+
+        :param Overwrite overwrite: Permission overwrite to edit.
+        :param Optional[str] reason: Reason of the action.
+        """
         return self.client.edit_channel_permissions(self, overwrite, reason=reason)
 
     def request_invites(self) -> "Invite.RESPONSE_AS_LIST":
+        """
+        Requests channel invites.
+
+        :return: List[:class:`~.Invite`]
+        """
         return self.client.request_channel_invites(self)
 
     def create_invite(self, **kwargs) -> "Invite.RESPONSE":
+        """
+        Creates channel invite.
+
+        :param Optional[int] max_age: Maximum age of the invite.
+        :param Optional[int] max_uses: Maximum use count of the invite.
+        :param Optional[bool] temporary: Whether this invite is temporary, meaning user will be kicked if role is not added.
+        :param Optional[bool] unique: Whether this invite is unique, meaning new code will be generated even if there is invite with same options.
+        :param target_type: Target type of the voice channel invite.
+        :type target_type: Optional[Union[int, InviteTargetTypes]]
+        :param target_user: Target user of the invite.
+        :param target_application: Target application of the invite.
+        :param Optional[str] reason: Reason of the action.
+        :return: :class:`~.Invite`
+        """
         return self.client.create_channel_invite(self, **kwargs)
 
-    def delete_permissions(self, overwrite, *, reason: str = None):
+    def delete_permissions(self, overwrite, *, reason: Optional[str] = None):
+        """
+        Deletes permissions.
+
+        :param overwrite: Target overwrite to delete. Accepts ID of the user or role.
+        :param Optional[str] reason: Reason of the action.
+        """
         return self.client.delete_channel_permission(self, overwrite, reason=reason)
 
     def follow(self, target_channel: "Channel.TYPING") -> "FollowedChannel.RESPONSE":
+        """
+        Follows this channel to target channel.
+        :param target_channel: Channel to receive published messages.
+        :return: :class:`~.FollowedChannel`
+        """
         return self.client.follow_news_channel(self, target_channel)
 
     def trigger_typing_indicator(self):
+        """
+        Triggers ``<client> is typing...`` on channel.
+        """
         return self.client.trigger_typing_indicator(self)
 
     def request_pinned_messages(self) -> "Message.RESPONSE_AS_LIST":
+        """
+        Requests pinned messages.
+
+        :return: List[:class:`~.Message`]
+        """
         return self.client.request_pinned_messages(self)
 
     def add_recipient(self, user: User.TYPING, access_token: str, nick: str):
+        """
+        Adds recipient to the group DM.
+
+        :param user: Recipient to add.
+
+        :param str access_token: OAuth2 access token to use.
+        :param str nick: Nickname to assign.
+        """
         if not self.type.group_dm:
             raise AttributeError("This type of channel is not allowed to add recipient.")
         return self.client.group_dm_add_recipient(self, user, access_token, nick)
 
     def remove_recipient(self, user: User.TYPING):
+        """
+        Removes recipient from the group DM.
+
+        :param user: Recipient to remove.
+        """
         if not self.type.group_dm:
             raise AttributeError("This type of channel is not allowed to remove recipient.")
         return self.client.group_dm_remove_recipient(self, user)
 
-    def start_thread(self, message: "Message.TYPING" = None, *, name: str, auto_archive_duration: int, reason: str = None) -> "Channel.RESPONSE":
+    def start_thread(self, message: "Message.TYPING" = None, *, name: str, auto_archive_duration: int, reason: Optional[str] = None) -> "Channel.RESPONSE":
+        """
+        Starts new thread.
+
+        .. note::
+            If ``message`` param is passed, type of thread will be always public regardless of what you've set to.
+
+        :param message: Message to create thread from.
+        :param str name: Name of the thread.
+        :param int auto_archive_duration: When to archive thread in minutes.
+        :param Optional[str] reason: Reason of the action.
+        :return: :class:`~.Channel`
+        """
         return self.client.start_thread(self, message, name=name, auto_archive_duration=auto_archive_duration, reason=reason)
 
     def join_thread(self):
+        """
+        Joins to thread.
+        """
         if not self.is_thread_channel():
             raise AttributeError("This type of channel is not allowed to join thread.")
         return self.client.join_thread(self)
 
     def add_thread_member(self, user: User.TYPING):
+        """
+        Adds member to thread.
+
+        :param user: User to add.
+        """
         if not self.is_thread_channel():
             raise AttributeError("This type of channel is not allowed to add thread member.")
         return self.client.add_thread_member(self, user)
 
     def leave_thread(self):
+        """
+        Leaves thread.
+        """
         if not self.is_thread_channel():
             raise AttributeError("This type of channel is not allowed to leave thread.")
         return self.client.leave_thread(self)
 
     def remove_thread_member(self, user: User.TYPING):
+        """
+        Removes member from thread.
+
+        :param user: User to remove.
+        """
         if not self.is_thread_channel():
             raise AttributeError("This type of channel is not allowed to remove thread member.")
         return self.client.remove_thread_member(self, user)
 
     def list_thread_members(self) -> "ThreadMember.RESPONSE_AS_LIST":
+        """
+        Returns list of members in thread.
+
+        :return: List[:class:`~.ThreadMember`]
+        """
         if not self.is_thread_channel():
             raise AttributeError("This type of channel is not allowed to list thread members.")
         return self.client.list_thread_members(self)
 
     def list_active_threads(self) -> "ListThreadsResponse.RESPONSE":
+        """
+        Returns list of active threads in channel.
+
+        :return: :class:`~.ListThreadsResponse`
+        """
         return self.client.list_active_threads(self)
 
-    def list_public_archived_threads(self, *, before: Union[str, datetime.datetime] = None, limit: int = None) -> "ListThreadsResponse.RESPONSE":
+    def list_public_archived_threads(self, *, before: Optional[Union[str, datetime.datetime]] = None, limit: Optional[int] = None) -> "ListThreadsResponse.RESPONSE":
+        """
+        Returns list of public archived threads in channel.
+
+        :param before: Timestamp to show threads before.
+        :type before: Optional[Union[str, datetime.datetime]]
+        :param Optional[int] limit: Limit of the number of the threads.
+        :return: :class:`~.ListThreadsResponse`
+        """
         return self.client.list_public_archived_threads(self, before=before, limit=limit)
 
-    def list_private_archived_threads(self, *, before: Union[str, datetime.datetime] = None, limit: int = None) -> "ListThreadsResponse.RESPONSE":
+    def list_private_archived_threads(self, *, before: Optional[Union[str, datetime.datetime]] = None, limit: Optional[int] = None) -> "ListThreadsResponse.RESPONSE":
+        """
+        Returns list of private archived threads in channel.
+
+        :param before: Timestamp to show threads before.
+        :type before: Optional[Union[str, datetime.datetime]]
+        :param Optional[int] limit: Limit of the number of the threads.
+        :return: :class:`~.ListThreadsResponse`
+        """
         return self.client.list_private_archived_threads(self, before=before, limit=limit)
 
-    def list_joined_private_archived_threads(self, *, before: Union[str, datetime.datetime] = None, limit: int = None) -> "ListThreadsResponse.RESPONSE":
+    def list_joined_private_archived_threads(self, *, before: Optional[Union[str, datetime.datetime]] = None, limit: Optional[int] = None) -> "ListThreadsResponse.RESPONSE":
+        """
+        Returns list of private archived threads that bot joined in channel.
+
+        :param before: Timestamp to show threads before.
+        :type before: Optional[Union[str, datetime.datetime]]
+        :param Optional[int] limit: Limit of the number of the threads.
+        :return: :class:`~.ListThreadsResponse`
+        """
         return self.client.list_joined_private_archived_threads(self, before=before, limit=limit)
 
     def archive(self, locked: bool = False):
+        """
+        Archives thread.
+
+        :param bool locked: whether to lock thread or not.
+        """
         if not self.is_thread_channel():
             raise AttributeError("This type of channel is not allowed to archive.")
         return self.modify(archived=True, locked=locked)
 
-    def to_position_param(self, position: int = None, lock_permissions: bool = None, parent: Union[int, str, Snowflake, "Channel"] = None) -> dict:
+    def to_position_param(self, position: Optional[int] = None, lock_permissions: Optional[bool] = None, parent: Optional["Channel.TYPING"] = None) -> dict:
+        """
+        Exports channel object to dict as position parameter format.
+
+        :param Optional[int] position: Position of the channel.
+        :param Optional[bool] lock_permissions: Whether to lock permissions.
+        :param parent: Parent category of the channel.
+        :return: dict
+        """
         if isinstance(parent, Channel) and not parent.type.guild_category:
             raise TypeError("parent must be category channel.")
         param = {
@@ -312,7 +444,14 @@ class Channel(DiscordObjectBase):
         }
         return param
 
-    def to_welcome_screen_channel(self, description: str, emoji: Emoji.TYPING = None) -> WelcomeScreenChannel:
+    def to_welcome_screen_channel(self, description: str, emoji: Optional[Emoji.TYPING] = None) -> WelcomeScreenChannel:
+        """
+        Exports channel object to welcome screen object.
+
+        :param str description: Description of the channel.
+        :param emoji: Emoji to use.
+        :return: :class:`~.WelcomeScreenChannel`
+        """
         emoji = from_emoji(emoji)
         emoji_id = emoji.split(":")[-1] if ":" in emoji else None
         emoji_name = emoji.split(":")[-2] if ":" in emoji else emoji
@@ -320,19 +459,37 @@ class Channel(DiscordObjectBase):
 
     @property
     def mention(self) -> str:
+        """
+        The string that mentions channel.
+
+        """
         return f"<#{self.id}>"
 
     @property
     def guild(self) -> Optional["Guild"]:
+        """
+        Guild that channel belongs to if applicable.
+
+        """
         if self.guild_id and self.client.has_cache:
             return self.client.cache.get(self.guild_id, "guild")  # noqa
 
     def is_messageable(self) -> bool:
+        """
+        Checks if channel is able to send messages.
+
+        :return: bool
+        """
         if self.is_thread_channel():
             return self.thread_metadata.archived
         return self.type.guild_text or self.type.guild_news or self.type.dm or self.type.group_dm
 
     def is_thread_channel(self) -> bool:
+        """
+        Checks if channel is a thread.
+
+        :return: bool
+        """
         return self.type.guild_news_thread or self.type.guild_public_thread or self.type.guild_private_thread
 
     def __repr__(self) -> str:
@@ -340,6 +497,9 @@ class Channel(DiscordObjectBase):
 
 
 class ChannelTypes(TypeBase):
+    """
+    Types of the channel.
+    """
     GUILD_TEXT = 0
     DM = 1
     GUILD_VOICE = 2
@@ -354,15 +514,24 @@ class ChannelTypes(TypeBase):
 
 
 class VideoQualityModes(TypeBase):
+    """
+    Types of the video quality modes.
+    """
     AUTO = 1
     FULL = 2
 
 
 class SendOnlyChannel:
+    """
+    Internal class representing temporary messageable channel.
+    """
     def __init__(self, client: "APIClient", channel_id: Snowflake.TYPING):
         self.client: "APIClient" = client
         self.id: Snowflake = Snowflake.ensure_snowflake(channel_id)
 
+    def __int__(self) -> int:
+        return int(self.id)
+
     def send(self, *args, **kwargs) -> "Message.RESPONSE":
         return self.client.create_message(self.id, *args, **kwargs)
 
@@ -371,6 +540,12 @@ class SendOnlyChannel:
 
 
 class Message(DiscordObjectBase):
+    """
+    Represents a Discord message.
+
+    Refer https://discord.com/developers/docs/resources/channel#message-object for attributes of the channel object.
+    """
+
     TYPING = Union[int, str, Snowflake, "Message"]
     RESPONSE = Union["Message", Awaitable["Message"]]
     RESPONSE_AS_LIST = Union[List["Message"], Awaitable[List["Message"]]]
@@ -432,7 +607,30 @@ class Message(DiscordObjectBase):
     def __str__(self) -> str:
         return self.content
 
-    def reply(self, content=None, **kwargs) -> "Message.RESPONSE":
+    def reply(self, content: Optional[str] = None, **kwargs) -> "Message.RESPONSE":
+        """
+        Replies to the message.
+
+        :param Optional[str] content: Content of the message.
+        :param embed: Embed of the message.
+        :type embed: Optional[Union[Embed, dict]]
+        :param embeds: List of embeds of the message.
+        :type embeds: Optional[List[Union[Embed, dict]]]
+        :param file: File of the message.
+        :type file: Optional[Union[io.FileIO, pathlib.Path, str]]
+        :param files: Files of the message.
+        :type files: Optional[List[Union[io.FileIO, pathlib.Path, str]]]
+        :param Optional[bool] tts: Whether to speak message.
+        :param allowed_mentions: :class:`~.AllowedMentions` to use for this request.
+        :type allowed_mentions: Optional[Union[AllowedMentions, dict]]
+        :param component: Component of the message.
+        :type component: Optional[Union[dict, Component]]
+        :param components: List of  components of the message.
+        :type components: Optional[List[Union[dict, Component]]]
+        :param Optional[Sticker] sticker: Sticker of the message.
+        :param Optional[List[Sticker]] stickers: Stickers of the message. Up to 3.
+        :return: :class:`~.Message`
+        """
         kwargs["message_reference"] = self
         mention = kwargs.pop("mention") if "mention" in kwargs.keys() else True
         allowed_mentions = kwargs.get("allowed_mentions", self.client.default_allowed_mentions or AllowedMentions(replied_user=mention)).copy()
@@ -441,6 +639,26 @@ class Message(DiscordObjectBase):
         return self.client.create_message(self.channel_id, content, **kwargs)
 
     def edit(self, **kwargs) -> "Message.RESPONSE":
+        """
+        Edits message.
+        
+        :param Optional[str] content: Content to edit.
+        :param embed: Embed to edit.
+        :type embed: Optional[Union[Embed, dict]]
+        :param embeds: Embeds to edit.
+        :type embeds: Optional[List[Union[Embed, dict]]]
+        :param Optional[FILE_TYPE] file: File to add.
+        :param Optional[List[FILE_TYPE]] files: Files to add.
+        :param allowed_mentions: Allowed mentions of the message.
+        :type allowed_mentions: Optional[Union[AllowedMentions, dict]]
+        :param attachments: Attachments to keep.
+        :type attachments: Optional[List[Union[Attachment, dict]]]
+        :param component: Component of the message to edit.
+        :type component: Optional[Union[dict, Component]]
+        :param components: Components of the message to edit.
+        :type components: Optional[List[Union[dict, Component]]]
+        :return: :class:`~.Message`
+        """
         if self.__webhook_token:
             kwargs["webhook_token"] = self.__webhook_token
             return self.client.edit_webhook_message(self.webhook_id, self, **kwargs)
@@ -451,7 +669,12 @@ class Message(DiscordObjectBase):
             return self.client.edit_interaction_response(**kwargs)
         return self.client.edit_message(self.channel_id, self.id, **kwargs)
 
-    def delete(self, *, reason: str = None):
+    def delete(self, *, reason: Optional[str] = None):
+        """
+        Deletes message.
+
+        :param Optional[str] reason: Reason of the action.
+        """
         if self.__webhook_token:
             return self.client.delete_webhook_message(self.webhook_id, self, webhook_token=self.__webhook_token)
         elif self.__interaction_token:
@@ -459,30 +682,68 @@ class Message(DiscordObjectBase):
         return self.client.delete_message(self.channel_id, self.id, reason=reason)
 
     def crosspost(self) -> "Message.RESPONSE":
+        """
+        Crossposts message.
+
+        :return: :class:`~.Message`
+        """
         return self.client.crosspost_message(self.channel_id, self.id)
 
     def create_reaction(self, emoji: Union[Emoji, str]):
+        """
+        Creates reaction.
+
+        :param emoji: Emoji for creating reaction.
+        :type emoji: Union[str, Emoji]
+        """
         return self.client.create_reaction(self.channel_id, self.id, emoji)
 
     def delete_reaction(self, emoji: Union[Emoji, str], user: User.TYPING = "@me"):
+        """
+        Deletes reaction.
+
+        :param emoji: Emoji of the reaction to delete.
+        :type emoji: Union[str, Emoji]
+        :param user: User to delete reaction of. Default "@me" which is the bot itself.
+        """
         return self.client.delete_reaction(self.channel_id, self.id, emoji, user)
 
-    def pin(self, *, reason: str = None):
+    def pin(self, *, reason: Optional[str] = None):
+        """
+        Pins message.
+
+        :param Optional[str] reason: Reason of the action.
+        """
         return self.client.pin_message(self.channel_id, self.id, reason=reason)
 
-    def unpin(self, *, reason: str = None):
+    def unpin(self, *, reason: Optional[str] = None):
+        """
+        Unpins message.
+
+        :param Optional[str] reason: Reason of the action.
+        """
         return self.client.unpin_message(self.channel_id, self.id, reason=reason)
 
-    def start_thread(self, *, name: str, auto_archive_duration: int, reason: str = None) -> Channel.RESPONSE:
+    def start_thread(self, *, name: str, auto_archive_duration: int, reason: Optional[str] = None) -> Channel.RESPONSE:
+        """
+        Starts new thread.
+        
+        :param str name: Name of the thread.
+        :param int auto_archive_duration: When to archive thread in minutes.
+        :param Optional[str] reason: Reason of the action.
+        :return: :class:`~.Channel`
+        """
         return self.client.start_thread(self.channel_id, self, name=name, auto_archive_duration=auto_archive_duration, reason=reason)
 
     @property
     def guild(self) -> Optional["Guild"]:
+        """Guild this message belongs to."""
         if self.guild_id and self.client.has_cache:
             return self.client.get(self.guild_id, "guild")
 
     @property
     def channel(self) -> Union[Channel, SendOnlyChannel]:
+        """Channel this message belongs to."""
         send_only = SendOnlyChannel(self.client, self.channel_id)
         if self.channel_id and self.client.has_cache:
             if self.guild_id:
@@ -498,6 +759,9 @@ class Message(DiscordObjectBase):
 
 
 class MessageTypes(TypeBase):
+    """
+    Types of the message.
+    """
     DEFAULT = 0
     RECIPIENT_ADD = 1
     RECIPIENT_REMOVE = 2
@@ -524,6 +788,12 @@ class MessageTypes(TypeBase):
 
 
 class MessageActivity:
+    """
+    Represents Message Activity.
+
+    :ivar MessageActivityTypes ~.type: Type of the message activity.
+    :ivar Optional[str] ~.party_id: ID of the party.
+    """
     def __init__(self, resp: dict):
         self.type: MessageActivityTypes = MessageActivityTypes(resp["type"])
         self.party_id: Optional[str] = resp.get("party_id")  # This is actually set as string in discord docs.
@@ -535,6 +805,9 @@ class MessageActivity:
 
 
 class MessageActivityTypes(TypeBase):
+    """
+    Types of the message activity.
+    """
     JOIN = 1
     SPECTATE = 2
     LISTEN = 3
@@ -542,6 +815,9 @@ class MessageActivityTypes(TypeBase):
 
 
 class MessageFlags(FlagBase):
+    """
+    Flags of the message.
+    """
     CROSSPOSTED = 1 << 0
     IS_CROSSPOST = 1 << 1
     SUPPRESS_EMBEDS = 1 << 2
