@@ -6,6 +6,7 @@ from .channel import Channel, Message, ThreadMember
 from .emoji import Emoji
 from .gateway import Activity
 from .guild import Guild, GuildMember, Integration
+from .guild_scheduled_event import GuildScheduledEvent
 from .invite import InviteTargetTypes
 from .permission import Role
 from .snowflake import Snowflake
@@ -327,6 +328,11 @@ class GuildRoleDelete(EventBase):
             return self.guild.get(self.role_id, "role")
 
 
+GuildScheduledEventCreate = GuildScheduledEvent
+GuildScheduledEventUpdate = GuildScheduledEvent
+GuildScheduledEventDelete = GuildScheduledEvent
+
+
 class IntegrationCreate(Integration):
     def __init__(self, client: "Client", resp: dict):
         super().__init__(client, resp)
